@@ -42,8 +42,8 @@ sudo apt-get -y install build-essential unzip rsync bc python3 p7zip-full
 curl -L https://github.com/kubernetes/minikube/raw/master/Makefile --output Makefile-head
 # ISO tags are of the form VERSION-TIMESTAMP-PR, so this grep finds that TIMESTAMP in the middle
 # if it doesn't exist, it will just return VERSION, which is covered in the if statement below
-HEAD_ISO_TIMESTAMP=$(egrep "ISO_VERSION \?= " Makefile-head | cut -d \" -f 2 | cut -d "-" -f 2)
-CURRENT_ISO_TS=$(egrep "ISO_VERSION \?= " Makefile | cut -d \" -f 2 | cut -d "-" -f 2)
+HEAD_ISO_TIMESTAMP=$(grep -E "ISO_VERSION \?= " Makefile-head | cut -d \" -f 2 | cut -d "-" -f 2)
+CURRENT_ISO_TS=$(grep -E "ISO_VERSION \?= " Makefile | cut -d \" -f 2 | cut -d "-" -f 2)
 if [[ $HEAD_ISO_TIMESTAMP != v* ]]; then
 	diff=$((CURRENT_ISO_TS-HEAD_ISO_TIMESTAMP))
 	if [[ $CURRENT_ISO_TS == v* ]] || [ $diff -lt 0 ]; then
@@ -55,7 +55,7 @@ rm Makefile-head
 
 if [[ -z $ISO_VERSION ]]; then
 	release=false
-	IV=$(egrep "ISO_VERSION \?=" Makefile | cut -d " " -f 3 | cut -d "-" -f 1)
+	IV=$(grep -E "ISO_VERSION \?=" Makefile | cut -d " " -f 3 | cut -d "-" -f 1)
 	now=$(date +%s)
 	export ISO_VERSION=$IV-$now-$ghprbPullId
 	export ISO_BUCKET=minikube-builds/iso/$ghprbPullId
@@ -114,9 +114,9 @@ else
 	make generate-docs
 
 	git add Makefile pkg/minikube/download/iso.go site/content/en/docs/commands/start.md
-	git commit -m "Update ISO to ${ISO_VERSION}"
+	git commit -m "Release: Update ISO to ${ISO_VERSION}"
 	git remote add minikube-bot git@github.com:minikube-bot/minikube.git
 	git push -f minikube-bot ${branch}
 
-	gh pr create --fill --base master --head minikube-bot:${branch}
+	gh pr create --fill --base master --head minikube-bot:${branch} -l "ok-to-test"
 fi
