@@ -21,19 +21,18 @@
 # MINIKUBE_LOCATION: GIT_COMMIT from upstream build.
 # COMMIT: Actual commit ID from upstream build
 # EXTRA_BUILD_ARGS (optional): Extra args to be passed into the minikube integrations tests
-# access_token: The Github API access token. Injected by the Jenkins credential provider.
+# access_token: The GitHub API access token. Injected by the Jenkins credential provider.
+
 set -e
 
-mkdir -p cron && gsutil -qm rsync "gs://minikube-builds/${MINIKUBE_LOCATION}/cron" cron || echo "FAILED TO GET CRON FILES"
-sudo install cron/cleanup_and_reboot_Linux.sh /etc/cron.hourly/cleanup_and_reboot || echo "FAILED TO INSTALL CLEANUP"
+ARCH="arm64"
+OS="linux"
+DRIVER="docker"
+JOB_NAME="$JOB_NAME"
+CONTAINER_RUNTIME="containerd"
+EXTERNAL="yes"
 
 # removing possible left over docker containers from previous runs
 docker rm -f -v "$(docker ps -aq)" >/dev/null 2>&1 || true
 
-ARCH="arm64" \
-OS="linux" \
-DRIVER="docker" \
-JOB_NAME="$JOB_NAME" \
-CONTAINER_RUNTIME="containerd" \
-EXTERNAL="yes" \
 source ./common.sh
