@@ -38,8 +38,11 @@ grep -E "^VERSION_MINOR \\?=" Makefile | grep "${VERSION_MINOR}"
 grep -E "^VERSION_BUILD \\?=" Makefile | grep "${VERSION_BUILD}"
 
 # Force go packages to the Jekins home directory
-export GOPATH=$HOME/go
+# export GOPATH=$HOME/go
+./hack/jenkins/installers/check_install_golang.sh "/usr/local"
 
+# Make sure docker is installed and configured
+./hack/jenkins/installers/check_install_docker.sh
 # Verify ISO exists
 echo "Verifying ISO exists ..."
 make verify-iso
@@ -61,10 +64,10 @@ env BUILD_IN_DOCKER=y \
   "out/minikube_${DEB_VERSION}-${DEB_REVISION}_armhf.deb" \
   "out/minikube_${DEB_VERSION}-${DEB_REVISION}_ppc64el.deb" \
   "out/minikube_${DEB_VERSION}-${DEB_REVISION}_s390x.deb" \
-  "out/docker-machine-driver-kvm2_${DEB_VERSION}-${DEB_REVISION}_amd64.deb" \
-  "out/docker-machine-driver-kvm2_${DEB_VERSION}-${DEB_REVISION}_arm64.deb"
+  "out/docker-machine-driver-kvm2_${DEB_VERSION}-${DEB_REVISION}_amd64.deb"
+  # "out/docker-machine-driver-kvm2_${DEB_VERSION}-${DEB_REVISION}_arm64.deb"
 
-env BUILD_IN_DOCKER=y
+env BUILD_IN_DOCKER=y \
   make \
   "out/minikube-${RPM_VERSION}-${RPM_REVISION}.x86_64.rpm" \
   "out/minikube-${RPM_VERSION}-${RPM_REVISION}.aarch64.rpm" \
@@ -97,8 +100,15 @@ make checksum
 # unversioned names to avoid updating upstream Kubernetes documentation each release
 cp "out/minikube_${DEB_VERSION}-0_amd64.deb" out/minikube_latest_amd64.deb
 cp "out/minikube_${DEB_VERSION}-0_arm64.deb" out/minikube_latest_arm64.deb
+cp "out/minikube_${DEB_VERSION}-0_armhf.deb" out/minikube_latest_armhf.deb
+cp "out/minikube_${DEB_VERSION}-0_ppc64el.deb" out/minikube_latest_ppc64el.deb
+cp "out/minikube_${DEB_VERSION}-0_s390x.deb" out/minikube_latest_s390x.deb
+
 cp "out/minikube-${RPM_VERSION}-0.x86_64.rpm" out/minikube-latest.x86_64.rpm
 cp "out/minikube-${RPM_VERSION}-0.aarch64.rpm" out/minikube-latest.aarch64.rpm
+cp "out/minikube-${RPM_VERSION}-0.armv7hl.rpm" out/minikube-latest.armv7hl.rpm
+cp "out/minikube-${RPM_VERSION}-0.ppc64le.rpm" out/minikube-latest.ppc64le.rpm
+cp "out/minikube-${RPM_VERSION}-0.s390x.rpm" out/minikube-latest.s390x.rpm
 
 gsutil -m cp out/* "gs://$BUCKET/releases/$TAGNAME/"
 
@@ -111,5 +121,20 @@ fi
 #echo "Updating Docker images ..."
 #make push-gvisor-addon-image push-storage-provisioner-manifest
 
+echo "Generating tarballs for kicbase images"
+# first get the correct tag of the kic base image
+KIC_VERSION=$(grep -E "Version =" pkg/drivers/kic/types.go | cut -d \" -f 2 | cut -d "-" -f 1)
+# then generate tarballs for all achitectures
+for ARCH in "amd64" "arm64" "arm/v7" "ppc64le" "s390x" 
+do
+  SUFFIX=$(echo $ARCH | sed 's/\///g')
+  IMAGE_NAME=kicbase/stable:${KIC_VERSION}
+  TARBALL_NAME=out/kicbase-${KIC_VERSION}-${SUFFIX}.tar
+  docker pull ${IMAGE_NAME} --platform linux/${ARCH}
+  docker image save ${IMAGE_NAME} -o ${TARBALL_NAME}
+  openssl sha256 "${TARBALL_NAME}" | awk '{print $2}' > "${TARBALL_NAME}.sha256"
+  docker rmi -f ${IMAGE_NAME}
+done
+
 echo "Updating latest bucket for ${VERSION} release ..."
 gsutil cp -r "gs://${BUCKET}/releases/${TAGNAME}/*" "gs://${BUCKET}/releases/latest/"
