@@ -18,6 +18,7 @@ package main
 
 import (
 	"context"
+	"fmt"
 	"os/exec"
 	"time"
 
@@ -39,11 +40,12 @@ func main() {
 	// get Docsy stable version
 	stable, err := update.StableVersion(ctx, "google", "docsy")
 	if err != nil {
-		klog.Fatalf("Unable to get Doscy stable version: %v", err)
+		klog.Fatalf("Unable to get Docsy stable version: %v", err)
 	}
-	klog.Infof("Doscy stable version: %s", stable)
 
 	if err := exec.CommandContext(ctx, "./update_docsy_version.sh", stable).Run(); err != nil {
 		klog.Fatalf("failed to update docsy commit: %v", err)
 	}
+
+	fmt.Print(stable)
 }
