@@ -138,7 +138,7 @@ func teePrefix(prefix string, r io.Reader, w io.Writer, logger func(format strin
 	if line.Len() > 0 {
 		logger("%s%s", prefix, line.String())
 	}
-	return nil
+	return scanner.Err()
 }
 
 // fileExists checks that the same file exists on the other end
@@ -209,5 +209,10 @@ func writeFile(dst string, f assets.CopyableFile, perms os.FileMode) error {
 	if n != int64(f.GetLength()) {
 		return fmt.Errorf("%s: expected to write %d bytes, but wrote %d instead", dst, f.GetLength(), n)
 	}
+
+	if err := w.Chmod(perms); err != nil {
+		return errors.Wrap(err, "chmod")
+	}
+
 	return w.Close()
 }
