@@ -18,6 +18,116 @@ package constants
 
 var (
 	KubeadmImages = map[string]map[string]string{
+		"v1.32.0": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.31.4": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.30.8": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.29.12": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.9",
+		},
+		"v1.32.0-rc.2": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.32.0-rc.1": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.32.0-rc.0": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.29.11": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.9",
+		},
+		"v1.31.3": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.30.7": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.32.0-beta.0": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.32.0-alpha.3": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.31.2": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.30.6": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.29.10": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.28.15": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.32.0-alpha.2": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.32.0-alpha.1": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.16-0",
+			"pause":           "3.10",
+		},
+		"v1.30.5": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.31.1": {
+			"coredns/coredns": "v1.11.3",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.10",
+		},
+		"v1.29.9": {
+			"coredns/coredns": "v1.11.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
+		"v1.28.14": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.15-0",
+			"pause":           "3.9",
+		},
 		"v1.30.4": {
 			"coredns/coredns": "v1.11.1",
 			"etcd":            "3.5.12-0",
