@@ -33,6 +33,7 @@ import (
 	"k8s.io/minikube/pkg/drivers/kic"
 	"k8s.io/minikube/pkg/drivers/kic/oci"
 	"k8s.io/minikube/pkg/minikube/config"
+	"k8s.io/minikube/pkg/minikube/detect"
 	"k8s.io/minikube/pkg/minikube/driver"
 	"k8s.io/minikube/pkg/minikube/localpath"
 	"k8s.io/minikube/pkg/minikube/registry"
@@ -151,6 +152,17 @@ var dockerVersionOrState = func() (string, registry.State) {
 		return "", registry.State{Error: err, Installed: false, Healthy: false, Fix: "Install Docker", Doc: docURL}
 	}
 
+	if detect.IsAmd64M1Emulation() {
+		return "", registry.State{
+			Reason:    "PROVIDER_DOCKER_INCORRECT_ARCH",
+			Installed: true,
+			Running:   true,
+			Error:     errors.New("Cannot use amd64 minikube binary to start minikube cluster with Docker driver on arm64 machine"),
+			Fix:       "Download and use arm64 version of the minikube binary",
+			Doc:       "https://minikube.sigs.k8s.io/docs/start/",
+		}
+	}
+
 	ctx, cancel := context.WithTimeout(context.Background(), 6*time.Second)
 	defer cancel()
 
@@ -277,6 +289,17 @@ func checkDockerDesktopVersion(version string) (s registry.State) {
 			Fix:       "Update Docker Desktop to 4.16.1 or greater",
 		}
 	}
+
+	if runtime.GOOS == "darwin" && currSemver.EQ(semver.MustParse("4.34.0")) {
+		return registry.State{
+			Reason:    "PROVIDER_DOCKER_DESKTOP_VERSION_BAD",
+			Running:   true,
+			Error:     errors.New("Docker Desktop 4.34.0 has a regression that prevents minikube from listing the containers"),
+			Installed: true,
+			Fix:       "Use a different Docker desktop version, more info at https://github.com/docker/cli/issues/5412",
+		}
+	}
+
 	return s
 }
 
