@@ -43,7 +43,7 @@ type gcpTracer struct {
 	parentCtx context.Context
 	trace.Tracer
 	spans   map[string]trace.Span
-	cleanup func()
+	cleanup func(context.Context) error
 }
 
 // StartSpan starts a span for the next step of
@@ -69,7 +69,9 @@ func (t *gcpTracer) Cleanup() {
 	if ok {
 		span.End()
 	}
-	t.cleanup()
+	if err := t.cleanup(context.Background()); err != nil {
+		klog.Warningf("Fail to cleanup the trace: %s", err)
+	}
 }
 
 func initGCPTracer() (*gcpTracer, error) {
@@ -78,23 +80,27 @@ func initGCPTracer() (*gcpTracer, error) {
 		return nil, fmt.Errorf("GCP tracer requires a valid GCP project id set via the %s env variable", ProjectEnvVar)
 	}
 
-	_, flush, err := texporter.InstallNewPipeline(
-		[]texporter.Option{
-			texporter.WithProjectID(projectID),
-		},
-		sdktrace.WithSampler(sdktrace.AlwaysSample()),
-	)
+	exporter, err := texporter.New([]texporter.Option{
+		texporter.WithProjectID(projectID),
+	}...)
 	if err != nil {
 		return nil, errors.Wrap(err, "installing pipeline")
 	}
 
+	tp := sdktrace.NewTracerProvider(
+		sdktrace.WithBatcher(exporter),
+		sdktrace.WithSampler(sdktrace.AlwaysSample()),
+	)
+
+	otel.SetTracerProvider(tp)
+
 	t := otel.Tracer(parentSpanName)
 
 	ctx, span := t.Start(context.Background(), parentSpanName)
 	return &gcpTracer{
 		projectID: projectID,
 		parentCtx: ctx,
-		cleanup:   flush,
+		cleanup:   tp.Shutdown,
 		Tracer:    t,
 		spans: map[string]trace.Span{
 			parentSpanName: span,
