@@ -20,10 +20,16 @@ package integration
 
 import (
 	"context"
+	"fmt"
 	"os"
 	"os/exec"
+	"regexp"
+	"runtime"
 	"strings"
 	"testing"
+	"time"
+
+	"k8s.io/minikube/pkg/minikube/constants"
 )
 
 // TestDockerFlags makes sure the --docker-env and --docker-opt parameters are respected
@@ -158,3 +164,94 @@ func TestForceSystemdEnv(t *testing.T) {
 		validateContainerdSystemd(ctx, t, profile)
 	}
 }
+
+// TestDockerEnvContainerd makes sure that minikube docker-env command works when the runtime is containerd
+func TestDockerEnvContainerd(t *testing.T) {
+	t.Log("running with", ContainerRuntime(), DockerDriver(), runtime.GOOS, runtime.GOARCH)
+	if ContainerRuntime() != constants.Containerd || !DockerDriver() || runtime.GOOS != "linux" {
+		t.Skip("skipping: TestDockerEnvContainerd can only be run with the containerd runtime on Docker driver")
+	}
+	profile := UniqueProfileName("dockerenv")
+	ctx, cancel := context.WithTimeout(context.Background(), Minutes(30))
+	defer CleanupWithLogs(t, profile, cancel)
+
+	// start the minikube with containerd runtime
+	args := append([]string{"start", "-p", profile}, StartArgs()...)
+	cmd := exec.CommandContext(ctx, Target(), args...)
+	startResult, err := Run(t, cmd)
+	if err != nil {
+		t.Errorf("failed to start minikube with args: %q : %v", startResult.Command(), err)
+	}
+	time.Sleep(time.Second * 10)
+
+	// execute 'minikube docker-env --ssh-host --ssh-add' and extract the 'DOCKER_HOST' environment value
+	cmd = exec.CommandContext(ctx, "/bin/bash", "-c", fmt.Sprintf("%s docker-env --ssh-host --ssh-add -p %s", Target(), profile))
+	result, err := Run(t, cmd)
+	if err != nil {
+		t.Errorf("failed to execute minikube docker-env --ssh-host --ssh-add, error: %v, output: %s", err, result.Output())
+	}
+
+	output := result.Output()
+	groups := regexp.MustCompile(`DOCKER_HOST="(\S*)"`).FindStringSubmatch(output)
+	if len(groups) < 2 {
+		t.Errorf("DOCKER_HOST doesn't match expected format, output is %s", output)
+	}
+	dockerHost := groups[1]
+	segments := strings.Split(dockerHost, ":")
+	if len(segments) < 3 {
+		t.Errorf("DOCKER_HOST doesn't match expected format, output is %s", dockerHost)
+	}
+
+	// get SSH_AUTH_SOCK
+	groups = regexp.MustCompile(`SSH_AUTH_SOCK=(\S*)`).FindStringSubmatch(output)
+	if len(groups) < 2 {
+		t.Errorf("failed to acquire SSH_AUTH_SOCK, output is %s", output)
+	}
+	sshAuthSock := groups[1]
+	// get SSH_AGENT_PID
+	groups = regexp.MustCompile(`SSH_AGENT_PID=(\S*)`).FindStringSubmatch(output)
+	if len(groups) < 2 {
+		t.Errorf("failed to acquire SSH_AUTH_PID, output is %s", output)
+	}
+	sshAgentPid := groups[1]
+
+	cmd = exec.CommandContext(ctx, "/bin/bash", "-c", fmt.Sprintf("SSH_AUTH_SOCK=%s SSH_AGENT_PID=%s DOCKER_HOST=%s docker version", sshAuthSock, sshAgentPid, dockerHost))
+
+	result, err = Run(t, cmd)
+	if err != nil {
+		t.Fatalf("failed to execute 'docker version', error: %v, output: %s", err, result.Output())
+	}
+	// if we are really connecting to nerdctld inside node, docker version output should have word 'nerdctl'
+	// If everything works properly, in the output of `docker version` you should be able to see something like
+	/*
+		Server:
+			nerdctl:
+			Version:          1.0.0
+			buildctl:
+			Version:          0.10.3
+			GitCommit:        c8d25d9a103b70dc300a4fd55e7e576472284e31
+			containerd:
+			Version:          1.6.10
+			GitCommit:        770bd0108c32f3fb5c73ae1264f7e503fe7b2661
+	*/
+	if !strings.Contains(result.Output(), "nerdctl") {
+		t.Fatal("failed to detect keyword 'nerdctl' in output of docker version")
+	}
+
+	// now try to build an image
+	cmd = exec.CommandContext(ctx, "/bin/bash", "-c", fmt.Sprintf("SSH_AUTH_SOCK=%s SSH_AGENT_PID=%s DOCKER_HOST=%s DOCKER_BUILDKIT=0 docker build -t local/minikube-dockerenv-containerd-test:latest testdata/docker-env", sshAuthSock, sshAgentPid, dockerHost))
+	result, err = Run(t, cmd)
+	if err != nil {
+		t.Errorf("failed to build images, error: %v, output:%s", err, result.Output())
+	}
+
+	// and check whether that image is really available
+	cmd = exec.CommandContext(ctx, "/bin/bash", "-c", fmt.Sprintf("SSH_AUTH_SOCK=%s SSH_AGENT_PID=%s DOCKER_HOST=%s docker image ls", sshAuthSock, sshAgentPid, dockerHost))
+	result, err = Run(t, cmd)
+	if err != nil {
+		t.Fatalf("failed to execute 'docker image ls', error: %v, output: %s", err, result.Output())
+	}
+	if !strings.Contains(result.Output(), "local/minikube-dockerenv-containerd-test") {
+		t.Fatal("failed to detect image 'local/minikube-dockerenv-containerd-test' in output of docker image ls")
+	}
+}
